@@ -239,9 +239,10 @@ print "\n\n\n\n\n\n\nWE SHOULD HAVE INSTALLED MARIADB=$stdout<==\n\n\n\n\n\n\n";
    foreach my $count (1..3) {
       ($stdout,$stderr)=$handle->cmd("sudo wget --random-wait --progress=dot ".
          "http://zlib.net/$zlib.tar.gz",'__display__');
-      $checksum='44d667c142d7cda120332623eab69f40';
+      $checksum=
+         '8d7e9f698ce48787b6e1c67e6bff79e487303e66077e25cb9784ac8835978017';
       ($stdout,$stderr)=$handle->cmd(
-         "sudo md5sum -c - <<<\"$checksum $zlib.tar.gz\"",
+         "sudo sha256sum -c - <<<\"$checksum $zlib.tar.gz\"",
          '__display__');
       unless ($stderr) {
          print(qq{ + CHECKSUM Test for $zlib *PASSED* \n});
